add_readme_to_vignette: Add README to vignette
Description
If a package does not have a vignette but has a README.md, make the contents of the README.md be the vignette
Usage
add_readme_to_vignette(
source,
vignette_title = NULL,
braced_vignette_title = "README",
vignette_slug = "README",
quiet = FALSE
)
Arguments
- source
String. The directory path where the package is deployed.
- vignette_title
String. The intended title of the vignette. If not provided, no title will be attached.
- braced_vignette_title
String. The title of the vignette.
- vignette_slug
String. filename to be used as the vignette. By default this will be README.
- quiet
Logical. Whether to message about what is happening.
Details
Review the DISCRIPTION file and file structure and add the necessary dependencies and files.
Examples
Run this codeif (FALSE) {
# In the package directory.
add_readme_to_vignette(".")
}
Run the code above in your browser using DataLab